/*
 * Copyright (C) 2009 Niek Linnenbank
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "string.h"

int strncpy(char *dest, const char *src, size_t sz)
{
    char *d;
    const char *s;
    int val = 0;
    
    d = dest;
    s = src;

    while ( *s != '\0' && sz != 0 )
    {
	*d++ = *s++;
        sz--;
	val++;
    }
    *d++ = '\0';
    return val;
}
